summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/yahoo/libkyahoo/bytestream.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/yahoo/libkyahoo/bytestream.cpp')
-rw-r--r--kopete/protocols/yahoo/libkyahoo/bytestream.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/protocols/yahoo/libkyahoo/bytestream.cpp b/kopete/protocols/yahoo/libkyahoo/bytestream.cpp
index 8ca3a4cd..384402e9 100644
--- a/kopete/protocols/yahoo/libkyahoo/bytestream.cpp
+++ b/kopete/protocols/yahoo/libkyahoo/bytestream.cpp
@@ -64,9 +64,9 @@ public:
};
//!
-//! Constructs a ByteStream object with parent \a parent.
-ByteStream::ByteStream(TQObject *parent)
-:TQObject(parent)
+//! Constructs a ByteStream object with tqparent \a tqparent.
+ByteStream::ByteStream(TQObject *tqparent)
+:TQObject(tqparent)
{
// kdDebug(14181) << k_funcinfo << endl;
d = new Private;